.model-benchmark-body .sly-markdown-widget .markdown-body { padding: 0; font-family: inherit; } .model-benchmark-body .sly-markdown-widget .markdown-body h2 { font-size: 18px; font-weight: 600; margin-bottom: 0px; border: 0; } .model-benchmark-body .sly-markdown-widget .markdown-body h3 { color: #949bab; font-size: 18px; margin-bottom: 7px; } .model-benchmark-body .sly-markdown-widget .markdown-body p { margin-bottom: 12px; } .model-benchmark-body .el-collapse { margin: 15px 0; box-shadow: 0 1px 2px rgba(0, 0, 0, 0.1); border-radius: 7px; width: fit-content; } .model-benchmark-body .el-collapse .el-collapse-item__header { background: transparent; padding-right: 15px; } .model-benchmark-body .model-info-block { display: flex; gap: 10px; align-items: center; margin: 0 0 15px; color: #778592; font-size: 13px; } .model-benchmark-body .model-info-block > div { display: flex; gap: 4px; align-items: center; } /* , .model-benchmark-body .sly-markdown-widget .markdown-body>*:last-child */ .model-benchmark-body .sly-iw-notification-box .notification-box.notification-box-info { width: fit-content; } .model-benchmark-body h1 { font-size: 20px; font-weight: bold; margin-bottom: 5px; } .model-benchmark-body .overview-info-block { background: #f4f7fb; border-radius: 12px; padding: 20px; } .model-benchmark-body .width-fit-content { width: fit-content;} .model-benchmark-body .overview-info-block ul { list-style: none; padding: 0; } .model-benchmark-body .overview-info-block ul p { padding: 0; } .model-benchmark-body .overview-info-block .checkpoint-url { display: inline-block; width: 250px; white-space: nowrap; overflow: hidden; text-overflow: ellipsis; vertical-align: middle; } .model-benchmark-body .sly-sidebar-widget .main-wrapper .sidebar-panel { top: 10px; } {{ layout }}